﻿using System;
using System.Linq;
using System.Collections.Generic;

using NorthwindCacheDemo.DTO;
using NorthwindCacheDemo.CL;
using NorthwindCacheDemo.DAL;

namespace NorthwindCacheDemo.BLL
{
    /// <summary>
    /// Provides business logic over the Northwind product catalog.
    /// The CatalogService class provides method that validate input,
    /// and retrieve transfer objects representing the product catalog.
    /// These methods will first validate input, then call to the underlying
    /// read-through cache layer to provide the caller with the requested
    /// product catalog transfer objects.
    /// </summary>
    public class CatalogService
    {
        public CatalogService() {}

        public IList<Category> GetCategories()
        {
            return CacheLayer.CatalogCache.GetCategories();
        }

        public Category GetCategory(int id)
        {
            if (id <= 0)
            {
                return null;
            }

            return CacheLayer.CatalogCache.GetCategory(id);
        }

        public Product GetProduct(int id)
        {
            if (id <= 0)
            {
                return null;
            }

            return CacheLayer.CatalogCache.GetProduct(id);
        }

        public IList<Product> GetProductsByCategory(int id)
        {
            if (id <= 0)
            {
                return null;
            }

            return CacheLayer.CatalogCache.GetProductsByCategory(id);
        }

        public IList<Product> GetPopularProducts()
        {
            return CacheLayer.CatalogCache.GetPopularProducts();
        }

        public IList<Product> GetPopularProductsByCategory(int id)
        {
            if (id <= 0)
            {
                return null;
            }

            return CacheLayer.CatalogCache.GetPopularProductsByCategory(id);
        }

        public IList<Product> GetAlsoPurchasedProducts(int id)
        {
            if (id <= 0)
            {
                return null;
            }

            return CacheLayer.CatalogCache.GetAlsoPurchasedProducts(id);
        }
    }
}
