﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Transactions;

using NorthwindCacheDemo.DTO;
using NorthwindCacheDemo.DAL;

namespace NorthwindCacheDemo.BLL
{
    /// <summary>
    /// Provides business logic over the Northwind order subject area.
    /// The ProcessOrder method within this class wraps calls to the
    /// data layer in a TransactionScope to robustly persist Order and
    /// OrderItems to the underlying data store.
    /// </summary>
    public class OrderService
    {
        public void ProcessOrder(ShoppingCart cart, 
            string name, string address, string city,
            string region, string postalCode, string country) 
        {
            using (TransactionScope scope = new TransactionScope())
            {
                Order order = new Order()
                {
                    OrderDate = DateTime.Now,
                    ShipName = name,
                    ShipAddress = address,
                    ShipCity = city,
                    ShipRegion = region,
                    ShipPostalCode = postalCode,
                    ShipCountry = country
                };

                int orderID = DataLayer.OrderProvider.InsertOrder(order);

                OrderItem orderItem = null;
                foreach (ShoppingCartItem cartItem in cart)
                {
                    orderItem = new OrderItem()
                    {
                        OrderID = orderID,
                        ProductID = cartItem.ProductID,
                        Quantity = cartItem.Quantity,
                        UnitPrice = cartItem.UnitPrice
                    };

                    DataLayer.OrderProvider.InsertOrderItem(orderItem);
                }

                scope.Complete();
            }
        }
    }
}
