﻿using System;
using System.Collections.Generic;

namespace NorthwindCacheDemo.DTO
{
    [Serializable]
    public class ShoppingCart : IEnumerable<ShoppingCartItem>
    {
        private IDictionary<int, ShoppingCartItem> _items;

        public ShoppingCart()
        {
            _items = new Dictionary<int, ShoppingCartItem>();
        }

        public ShoppingCartItem this[int productID]
        {
            get
            {
                ShoppingCartItem item = null;

                if (_items.TryGetValue(productID, out item))
                {
                    return item;
                }
                
                return null;
            }
            set
            {
                if (value == null)
                {
                    _items.Remove(productID);
                }
                else
                {
                    _items[productID] = value;
                }
            }
        }

        public bool IsEmpty
        {
            get 
            {
                return (_items.Count == 0);
            }
        }

        public decimal Total
        {
            get
            {
                decimal total = 0;
                foreach (ShoppingCartItem item in _items.Values)
                {
                    total += (item.UnitPrice * item.Quantity);
                }
                return total;
            }
        }

        public IEnumerator<ShoppingCartItem> GetEnumerator()
        {
            foreach (ShoppingCartItem item in _items.Values)
            {
                yield return item;
            }
        }

        System.Collections.IEnumerator System.Collections.IEnumerable.GetEnumerator()
        {
            foreach (ShoppingCartItem item in _items.Values)
            {
                yield return item;
            }
        }
    }
}
