﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

using NorthwindCacheDemo.DTO;
using NorthwindCacheDemo.BLL;

public partial class Cart : System.Web.UI.Page
{
    protected void Page_Load(object sender, EventArgs e)
    {
        if (!IsPostBack)
        {
            ShoppingCart cart = (ShoppingCart)Session["ShoppingCart"];

            RenderView(cart);
        }
    }

    private void RenderView(ShoppingCart cart)
    {
        if (cart == null || cart.IsEmpty)
        {
            // show no cart message
            ShoppingPanel.Visible = false;
            Message.Visible = true;
        }
        else
        {
            ShoppingPanel.Visible = true;
            Message.Visible = false;

            CartGridView.DataSource = cart;
            CartGridView.DataBind();
            TotalLabel.Text = String.Format("{0:c}", cart.Total);
        }
    }

    protected void UpdateCartButton_Click(object sender, EventArgs e)
    {
        ShoppingCart cart = (ShoppingCart)Session["ShoppingCart"];
        UpdateCart(cart);
        RenderView(cart);
    }

    private void UpdateCart(ShoppingCart cart)
    {
        foreach (GridViewRow r in CartGridView.Rows)
        {
            Label productIDLabel = (Label)r.FindControl("ProductIDLabel");
            int productID = Convert.ToInt32(productIDLabel.Text);

            CheckBox remove = (CheckBox)r.FindControl("RemoveCheckBox");
            TextBox quantityTextBox = (TextBox)r.FindControl("QuantityTextBox");
            int quantity = Convert.ToInt32(quantityTextBox.Text);
            if (remove.Checked || quantity <= 0)
            {
                cart[productID] = null;
                continue;
            }

            cart[productID].Quantity = quantity;
        }
    }

    protected void CartGridView_RowDataBound(object sender, GridViewRowEventArgs e)
    {
        if (e.Row.RowType != DataControlRowType.DataRow)
        {
            return;
        }

        ShoppingCartItem cartItem = (ShoppingCartItem)e.Row.DataItem;

        Product p = ServiceLayer.CatalogService.GetProduct(cartItem.ProductID);

        Label productIDLabel = (Label)e.Row.FindControl("ProductIDLabel");
        HyperLink productLink = (HyperLink)e.Row.FindControl("ProductLink");
        Label unitPriceLabel = (Label)e.Row.FindControl("UnitPriceLabel");
        TextBox quantityTextBox = (TextBox)e.Row.FindControl("QuantityTextBox");

        productIDLabel.Text = cartItem.ProductID.ToString();
        productLink.Text = p.Name;
        productLink.NavigateUrl = String.Format("~/Product.aspx?id={0}", cartItem.ProductID);
        unitPriceLabel.Text = String.Format("{0:c}", cartItem.UnitPrice);
        quantityTextBox.Text = cartItem.Quantity.ToString();
    }

    protected void CheckoutButton_Click(object sender, EventArgs e)
    {
        ShoppingCart cart = (ShoppingCart)Session["ShoppingCart"];
        UpdateCart(cart);

        if (cart.IsEmpty)
        {
            RenderView(cart);
        }
        else
        {
            Response.Redirect("~/Purchase.aspx");
        }
    }
}
