﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

using NorthwindCacheDemo.DTO;
using NorthwindCacheDemo.BLL;

public partial class _Product : System.Web.UI.Page
{
    protected void Page_Load(object sender, EventArgs e)
    {
        if (!IsPostBack)
        {
            int id = Convert.ToInt32(Request.Params["id"]);

            Product p = ServiceLayer.CatalogService.GetProduct(id);
            Category c = ServiceLayer.CatalogService.GetCategory(p.CategoryID);
            IList<Product> products = ServiceLayer.CatalogService.GetAlsoPurchasedProducts(id);

            RenderView(p, c, products);
        }
    }

    private void RenderView(Product p, Category c, IList<Product> products)
    {
        ProductTitleLabel.Text = p.Name;
        ProductImage.ImageUrl = String.Format("~/images/{0}.jpg", p.CategoryID);

        ProductNameLabel.Text = p.Name;
        QuantityPerUnitLabel.Text = p.QuantityPerUnit;
        UnitPriceLabel.Text = String.Format("{0:c}", p.UnitPrice);

        CategoryLink.NavigateUrl = String.Format("~/Catalog.aspx?id={0}", c.CategoryID);
        CategoryLink.Text = c.Name;

        ProductGridView.DataSource = products;
        ProductGridView.DataBind();
    }

    protected void AddToCartButton_Click(object sender, EventArgs e)
    {
        ShoppingCart cart = (ShoppingCart)Session["ShoppingCart"];

        if (cart == null)
        {
            cart = new ShoppingCart();
            Session["ShoppingCart"] = cart;
        }

        int productID = Convert.ToInt32(Request.Params["id"]);

        ShoppingCartItem item = cart[productID];
        if (item != null)
        {
            item.Quantity++;
        }
        else
        {
            Product p = ServiceLayer.CatalogService.GetProduct(productID);

            cart[productID] = new ShoppingCartItem()
            {
                ProductID = productID,
                Quantity = 1,
                UnitPrice = p.UnitPrice
            };
        }

        Response.Redirect("~/Cart.aspx");
    }
}
