﻿using System;
using System.Collections.Generic;
using System.Data.Caching;

using NorthwindCacheDemo.DTO;

namespace VelocityClientConsole
{
    class CatalogRegionSample
    {
        static void Main(string[] args)
        {
            // Create the catalog cache object
            CacheFactory factory = new CacheFactory();
            Cache catalogCache = factory.GetCache("catalog");

            // Create a category region with eviction disabled
            catalogCache.CreateRegion("BeveragesRegion", false);
            catalogCache.CreateRegion("ProduceRegion", false);

            // Build catalog
            catalogCache.Put("Category-1", new Category() { Name = "Beverages" });
            catalogCache.Put("Category-7", new Category() { Name = "Produce" });
            catalogCache.Put("BeveragesRegion", "Product-1", new Product() { Name = "Chai" });
            catalogCache.Put("BeveragesRegion", "Product-43", new Product() { Name = "Coffee" });
            catalogCache.Put("ProduceRegion", "Product-7", new Product() { Name = "Pears" });
            catalogCache.Put("ProduceRegion", "Product-51", new Product() { Name = "Apples" });

            // Retrieve the products in the Category-1 region
            IEnumerator<KeyValuePair<string, object>> enumerator = catalogCache.GetEnumerator("BeveragesRegion");

            Product p = null;
            while (enumerator.MoveNext())
            {
                p = (Product)enumerator.Current.Value;
                Console.WriteLine(p.Name);
            }

            // Retrieve an individual product in the ProduceRegion
            p = (Product)catalogCache.Get("ProduceRegion", "Product-51");

            Console.WriteLine(p.Name);

            catalogCache.Remove("Category-1");
            catalogCache.Remove("Category-7");
            catalogCache.RemoveRegion("BeveragesRegion");
            catalogCache.RemoveRegion("ProduceRegion");

            Console.ReadLine();
        }
    }
}
