﻿using System;
using System.Collections.Generic;
using System.Data.Caching;

using NorthwindCacheDemo.DTO;

namespace VelocityClientConsole
{
    class ReportSample
    {
        static void Main(string[] args)
        {
            // Create catalog cache object
            CacheFactory factory = new CacheFactory();
            Cache catalogCache = factory.GetCache("catalog");
            Cache reportCache = factory.GetCache("reports");

            // Build catalog
            catalogCache.Put("Category-1", new Category() { Name = "Beverages" });
            catalogCache.Put("Category-7", new Category() { Name = "Produce" });
            catalogCache.Put("Product-1", new Product() { Name = "Chai" });
            catalogCache.Put("Product-43", new Product() { Name = "Coffee" });
            catalogCache.Put("Product-7", new Product() { Name = "Pears" });
            catalogCache.Put("Product-51", new Product() { Name = "Apples" });

            // Create category lists
            IList<string> beverageIDs = new List<string>();
            beverageIDs.Add("Product-1");
            beverageIDs.Add("Product-43");
            catalogCache.Put("ProductList-1", beverageIDs);

            IList<string> produceIDs = new List<string>();
            produceIDs.Add("Product-7");
            produceIDs.Add("Product-51");
            catalogCache.Put("ProductList-7", produceIDs);

            // Create top selling product id list, and add to reports cache
            IList<string> topSellerIDs = new List<string>();
            topSellerIDs.Add("Product-43");
            topSellerIDs.Add("Product-51");

            reportCache.Put("TopSellingList", topSellerIDs);

            // Get the top selling product id list from the reports cache
            topSellerIDs = (List<string>)reportCache.Get("TopSellingList");

            // Iterate through id list, and retrieve products from cache
            Product p = null;
            foreach (string id in topSellerIDs)
            {
                p = (Product)catalogCache.Get(id);
                Console.WriteLine(p.Name);
            }

            reportCache.Remove("TopSellingList");
            catalogCache.Remove("ProductList-1");
            catalogCache.Remove("ProductList-7");
            catalogCache.Remove("Category-1");
            catalogCache.Remove("Category-7");
            catalogCache.Remove("Product-1");
            catalogCache.Remove("Product-43");
            catalogCache.Remove("Product-7");
            catalogCache.Remove("Product-51");
            
            Console.ReadLine();
        }
    }
}
